icclim
======

icclim (Index Calculation CLIMate) is a Python library for climate indices calculation.

This open-source project has been possible thanks to funding by the European Commission Projects FP7-IS-ENES2 (2013-2017) and FP7-CLIPC (2013-2016).
It is used as a backend on the C4I platform http://climate4impact.eu and on the CLIPC Portal http://www.clipc.eu

It is lead by CERFACS, a research institution located in Toulouse, France.

For documentation please visit: http://icclim.readthedocs.org

Quick Install Instructions
--------------------------
pip install icclim


Indices
--------------------------
For a detailed description of each ECA index, please visit: https://www.ecad.eu/documents/atbd.pdf
